Bifrost: CCDBG_Build_opt Struct Reference

Bifrost

Data Fields
CCDBG_Build_opt Struct Reference

This structure inherits from CDBG_Build_opt and introduces only a few new members which are color-related. More...

Inherits CDBG_Build_opt.

## Data Fields
string | filename_colors_in
| String containing the name of a Bifrost color file to read in ColoredCDBG<U>::read(). More...
bool | outputColors
| Boolean indicating if the graph should be colored or not. More...
Data Fields inherited from CDBG_Build_opt
bool | verbose
| Print information messages during execution if true. More...
size_t | nb_threads
| Number of threads to use for building the graph. More...
size_t | read_chunksize
| Number of reads a thread can read and process at a time. More...
size_t | nb_bits_unique_kmers_bf
| Number of Bloom filter bits per k-mer occurring at least once in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in. More...
size_t | nb_bits_non_unique_kmers_bf
| Number of Bloom filter bits per k-mer occurring at least twice in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in. More...
string | inFilenameBBF
| String containing the name of a Bloom filter file that is generated by CompactedDBG<U, G>::filter. More...
string | outFilenameBBF
| String containing the name of a Bloom filter file that will be generated by CompactedDBG<U, G>::filter. More...
vector< string > | filename_seq_in
| Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction. More...
vector< string > | filename_ref_in
| Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction. More...
size_t | k
| Length of k-mers (not used by CompactedDBG<U, G>::build). More...
size_t | g
| Length of g-mers, the minimizers, such that g < k (not used by CompactedDBG<U, G>::build). More...
bool | build
| Boolean indicating if the graph must be built. More...
bool | update
| Boolean indicating if the graph must be updated. More...
bool | clipTips
| Clip short tips (length < 2k) of the graph (not used by CompactedDBG<U, G>::build). More...
bool | deleteIsolated
| Remove short isolated unitigs (length < 2k) of the graph (not used by CompactedDBG<U, G>::build). More...
bool | useMercyKmers
| Keep in the graph low coverage k-mers (cov=1) connecting tips of the graph. More...
bool | outputGFA
| Boolean indicating if the graph is written to a GFA file (true) or if the unitigs are written to a FASTA file (false). More...
string | prefixFilenameOut
| Prefix for the name of the file to which the graph must be written. More...
string | filename_graph_in
| String containing the name of a GFA file to read using CompactedDBG<U, G>::read. More...

## Detailed Description

This structure inherits from CDBG_Build_opt and introduces only a few new members which are color-related.

See the documentation of CDBG_Build_opt for the inherited members. An example of using such a structure is shown in src/Bifrost.cpp.

## Field Documentation

## ◆ filename_colors_in

CCDBG_Build_opt::filename_colors_in

String containing the name of a Bifrost color file to read in ColoredCDBG<U>::read().

Default is an empty string (no file specified).

## ◆ outputColors

CCDBG_Build_opt::outputColors

Boolean indicating if the graph should be colored or not.

This member is not used by any function of ColoredCDBG<U> or CompactedDBG<U, T>. It is used by the Bifrost CLI. Default is true.

The documentation for this struct was generated from the following file:

- src/ColoredCDBG.hpp